@@ -30,7 +30,7 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$canDo = CitationsHelper::getActions('sponsor');
+$canDo = CitationsHelperPermissions::getActions('sponsor');
 
 JToolBarHelper::title(JText::_('CITATIONS') . ': ' . JText::_('CITATION_SPONSORS'), 'citation.png');
 if ($canDo->get('core.create'))
