@@ -185,7 +185,7 @@ class CoursesControllerAssets extends \Hubzero\Component\AdminController
 	public function unlinkTask()
 	{
 		// Check for request forgeries
-		JRequest::checkToken('get') or JRequest::checkToken() or jexit('Invalid Token');
+		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
 
 		// Incoming
 		$asset_id  = JRequest::getInt('asset', 0);
