@@ -152,6 +152,10 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 			$this->view->row->set('created_by', $this->juser->get('id'));
 		}
 
+		JFactory::getApplication()->setUserState('com_forum.edit.section.data', array(
+			'id'       => $this->view->row->get('id'),
+			'asset_id' => $this->view->row->get('asset_id')
+		));
 		$m = new ForumModelAdminSection();
 		$this->view->form = $m->getForm();
 
@@ -185,10 +189,23 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 		// Check for request forgeries
 		JRequest::checkToken() or jexit('Invalid Token');
 
+		JFactory::getApplication()->setUserState('com_forum.edit.section.data', null);
+
 		// Incoming
 		$fields = JRequest::getVar('fields', array(), 'post');
 		$fields = array_map('trim', $fields);
 
+		// Bind the rules.
+		$data = JRequest::getVar('jform', array(), 'post');
+		if (isset($data['rules']) && is_array($data['rules']))
+		{
+			$model = new ForumModelAdminSection();
+			$form = $model->getForm($data, false);
+			$validData = $model->validate($form, $data);
+
+			$fields['rules'] = $validData['rules'];
+		}
+
 		// Initiate extended database class
 		$row = new ForumModelSection($fields['id']);
 		if (!$row->bind($fields))
@@ -311,7 +328,7 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 	public function stateTask($state=0)
 	{
 		// Check for request forgeries
-		JRequest::checkToken('get') or JRequest::checkToken() or jexit('Invalid Token');
+		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
 
 		// Incoming
 		$ids = JRequest::getVar('id', array());
@@ -372,7 +389,7 @@ class ForumControllerSections extends \Hubzero\Component\AdminController
 	public function accessTask()
 	{
 		// Check for request forgeries
-		JRequest::checkToken('get') or JRequest::checkToken() or jexit('Invalid Token');
+		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
 
 		// Incoming
 		$state = JRequest::getInt('access', 0);
