@@ -39,7 +39,7 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 	/**
 	 * Display a list of all categories
 	 *
-	 * @return     void
+	 * @return  void
 	 */
 	public function displayTask()
 	{
@@ -51,9 +51,9 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 		$this->view->filters = array(
 			'state'  => -1,
 			'access' => -1,
-			'empty'	 => 1
+			'empty'  => 1
 		);
-		$this->view->filters['section']        = $app->getUserStateFromRequest(
+		$this->view->filters['section'] = $app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.id',
 			'id',
 			0,
@@ -61,33 +61,32 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 		);
 		if (!$this->view->filters['section'])
 		{
-			$this->view->filters['section']        = $app->getUserStateFromRequest(
+			$this->view->filters['section'] = $app->getUserStateFromRequest(
 				$this->_option . '.' . $this->_controller . '.cid',
 				'cid',
 				0,
 				'int'
 			);
 		}
-		$this->view->filters['sort']         = trim($app->getUserStateFromRequest(
+		$this->view->filters['sort'] = trim($app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.sort',
 			'filter_order',
 			'a.title'
 		));
-		$this->view->filters['sort_Dir']     = trim($app->getUserStateFromRequest(
+		$this->view->filters['sort_Dir'] = trim($app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.sortdir',
 			'filter_order_Dir',
 			'ASC'
 		));
-		//$this->view->filters['filterby']       = $this->view->filters['sort'] . ' ' . $this->view->filters['sort_Dir'];
 
 		// Get paging variables
-		$this->view->filters['limit']        = $app->getUserStateFromRequest(
+		$this->view->filters['limit'] = $app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.limit',
 			'limit',
 			$config->getValue('config.list_limit'),
 			'int'
 		);
-		$this->view->filters['start']        = $app->getUserStateFromRequest(
+		$this->view->filters['start'] = $app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.limitstart',
 			'limitstart',
 			0,
@@ -126,7 +125,7 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 	/**
 	 * Create a new category
 	 *
-	 * @return     void
+	 * @return  void
 	 */
 	public function addTask()
 	{
@@ -136,14 +135,12 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 	/**
 	 * Edit a category
 	 *
-	 * @return     void
+	 * @return  void
 	 */
 	public function editTask($row=null)
 	{
 		JRequest::setVar('hidemainmenu', 1);
 
-		$this->view->setLayout('edit');
-
 		if (is_object($row))
 		{
 			$this->view->row = $row;
@@ -174,22 +171,21 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 		*/
 
 		// Set any errors
-		if ($this->getError())
+		foreach ($this->getErrors() as $error)
 		{
-			foreach ($this->getErrors() as $error)
-			{
-				$this->view->setError($error);
-			}
+			$this->view->setError($error);
 		}
 
 		// Output the HTML
-		$this->view->display();
+		$this->view
+			->setLayout('edit')
+			->display();
 	}
 
 	/**
 	 * Save a category and come back to the edit form
 	 *
-	 * @return     void
+	 * @return  void
 	 */
 	public function applyTask()
 	{
@@ -199,8 +195,8 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 	/**
 	 * Save a category
 	 *
-	 * @param      integer $redirect Redirect the page after saving
-	 * @return     void
+	 * @param   boolean  $redirect  Redirect the page after saving
+	 * @return  void
 	 */
 	public function saveTask($redirect=true)
 	{
@@ -208,13 +204,24 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 		JRequest::checkToken() or jexit('Invalid Token');
 
 		// Incoming
-		$fields = JRequest::getVar('fields', array(), 'post');
+		$fields   = JRequest::getVar('fields', array(), 'post');
+		$articles = null;
 
 		// Initiate extended database class
 		$row = new KbModelCategory($fields['id']);
+
+		// Did the parent category change?
+		if ($row->exists())
+		{
+			if ($fields['section'] != $row->get('section'))
+			{
+				$articles = $row->articles('list', array('state' => -1));
+			}
+		}
+
 		if (!$row->bind($fields))
 		{
-			$this->addComponentMessage($row->getError(), 'error');
+			JFactory::getApplication()->enqueueMessage($row->getError(), 'error');
 			$this->editTask($row);
 			return;
 		}
@@ -227,16 +234,34 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 		// Store new content
 		if (!$row->store(true))
 		{
-			$this->addComponentMessage($row->getError(), 'error');
+			JFactory::getApplication()->enqueueMessage($row->getError(), 'error');
 			$this->editTask($row);
 			return;
 		}
 
+		// Update articles if category parent has changed
+		if ($articles)
+		{
+			$sec = $row->get('id');
+			$cat = 0;
+			if ($row->get('section'))
+			{
+				$sec = $row->get('section', 0);
+				$cat = $row->get('id');
+			}
+			foreach ($articles as $article)
+			{
+				$article->set('section', $sec);
+				$article->set('category', $cat);
+				$article->store(false);
+			}
+		}
+
 		if ($redirect)
 		{
 			// Redirect
 			$this->setRedirect(
-				'index.php?option='.$this->_option . '&controller=' . $this->_controller,
+				'index.php?option='.$this->_option . '&controller=' . $this->_controller . ($articles ? '&id=0' : ''),
 				JText::_('COM_KB_CATEGORY_SAVED')
 			);
 			return;
@@ -248,7 +273,7 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 	/**
 	 * Remove an entry
 	 *
-	 * @return     void
+	 * @return  void
 	 */
 	public function removeTask()
 	{
@@ -260,6 +285,8 @@ class KbControllerCategories extends \Hubzero\Component\AdminController
 		switch ($step)
 		{
 			case 1:
+				JRequest::setVar('hidemainmenu', 1);
+
 				// Incoming
 				$id = JRequest::getVar('id', array(0));
 				if (is_array($id) && !empty($id))
