@@ -163,6 +163,9 @@ $this->css()
 			</a>
 		</p>
 
+		<?php echo JHTML::_('form.token'); ?>
+		<?php echo JHTML::_('form.honeypot'); ?>
+
 		<input type="hidden" name="created_by" value="<?php echo $this->row->created_by; ?>" />
 		<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 		<input type="hidden" name="task" value="save" />
