@@ -295,6 +295,14 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 			$this->view->relpath = '/uploads';
 		}
 
+		$this->view->relpath = JPath::clean($this->view->relpath);
+		$this->view->relpath = explode('/', $this->view->relpath);
+		foreach ($this->view->relpath as $i => $p)
+		{
+			$this->view->relpath[$i] = preg_replace('/[^a-zA-Z0-9_\-]/', '', $p);
+		}
+		$this->view->relpath = implode(DS, $this->view->relpath);
+
 		//build path to the group folder
 		$this->path = rtrim($this->path, DS) . $this->view->relpath;
 
@@ -440,6 +448,9 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 	 */
 	public function doUpload()
 	{
+		// Check for request forgeries
+		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
+
 		// var to hold potential error
 		$returnObj          = new stdClass;
 		$returnObj->error   = false;
@@ -571,6 +582,9 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 	 */
 	public function ajaxuploadTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken(array('get', 'post')) or jexit('Invalid Token');
+
 		//get config
 		$config = JComponentHelper::getParams('com_media');
 
@@ -767,6 +781,9 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 	 */
 	public function doMoveFileTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// get request vars
 		$file   = JRequest::getVar('file', '');
 		$folder = JRequest::getVar('folder', '');
@@ -829,6 +846,9 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 	 */
 	public function doRenameFileTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// get request vars
 		$file = JRequest::getVar('file', '');
 		$name = JRequest::getVar('name', '');
@@ -902,6 +922,9 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 	 */
 	public function deletefileTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// Incoming file
 		$file = trim(JRequest::getVar('file', '', 'get'));
 		$file = $this->path . $file;
@@ -969,6 +992,9 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 	 */
 	public function saveFolderTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		//get request vars
 		$name   = JRequest::getCmd('name', '');
 		$folder = JRequest::getVar('folder', '');
@@ -1035,6 +1061,9 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 	 */
 	public function doRenameFolderTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// get request vars
 		$folder = JRequest::getVar('folder', '');
 		$name   = JRequest::getCmd('name', '');
@@ -1125,6 +1154,9 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 	 */
 	public function doMoveFolderTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// get request vars
 		$current = JRequest::getVar('current', '');
 		$folder  = JRequest::getVar('folder', '');
@@ -1169,6 +1201,9 @@ class GroupsControllerMedia extends GroupsControllerAbstract
 	 */
 	public function deleteFolderTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		//get request vars
 		$folder = JRequest::getVar('folder', '');
 
