@@ -95,6 +95,11 @@ class GroupsModelPageVersionArchive extends \Hubzero\Base\Model
 						$filters['pageid'] = 0;
 					}
 
+					if (!isset($filters['limit']))
+					{
+						$filters['limit'] = 25;
+					}
+
 					if ($results = $tbl->find($filters))
 					{
 						foreach ($results as $key => $result)
