@@ -82,7 +82,6 @@ class MembersControllerOrcid extends \Hubzero\Component\SiteController
 	private function _parseTree($root)
 	{
 		$records = array();
-
 		foreach ($root->children() as $child)
 		{
 			if ($child->getName() == 'orcid-search-results')
@@ -117,7 +116,7 @@ class MembersControllerOrcid extends \Hubzero\Component\SiteController
 	{
 		$srv = $this->config->get('orcid_service', 'members');
 
-		$url = JURI::getInstance()->getScheme() . '://' . $this->_services[$srv] . '/search/orcid-bio?q=';
+		$url = JURI::getInstance()->getScheme() . '://' . $this->_services[$srv] . '/v1.2/search/orcid-bio?q=';
 		$tkn = $this->config->get('orcid_' . $srv . '_token', '8b9f8396-0e9d-4b74-96b0-fbcfdc678716');
 
 		$bits = array();
@@ -137,7 +136,7 @@ class MembersControllerOrcid extends \Hubzero\Component\SiteController
 			$bits[] = 'email:' . $email;
 		}
 
-		$url .= implode('+AND+', $bits);
+		$url .= implode('&', $bits);
 
 		$initedCurl = curl_init();
 		curl_setopt($initedCurl, CURLOPT_URL, $url);
@@ -183,6 +182,7 @@ class MembersControllerOrcid extends \Hubzero\Component\SiteController
 			'name'   => $this->_controller,
 			'layout' => 'results'
 		));
+
 		$view->records = $records;
 		$view->callbackPrefix = $callbackPrefix;
 
@@ -244,6 +244,7 @@ class MembersControllerOrcid extends \Hubzero\Component\SiteController
 	 * Fetch...
 	 *
 	 * @param   boolean  $is_return
+	 * @todo    ORCiD's API does not return the best results. Search first name, last name, and email individually
 	 * @return  void
 	 */
 	public function fetchTask($is_return = false)
@@ -263,17 +264,57 @@ class MembersControllerOrcid extends \Hubzero\Component\SiteController
 			$callbackPrefix = "HUB.Members.Profile.";
 		}
 
-		$root = $this->_fetchXml($first_name, $last_name, $email);
+		/*
+		 * Separeted into three requests for better results
+		 */
 
-		if (!empty($root))
+		// get results based on first name
+		if (isset($first_name))
 		{
-			$records = $this->_parseTree($root);
+			$root = $this->_fetchXml($first_name, NULL, NULL);
+
+			if (!empty($root))
+			{
+				$fnames = $this->_parseTree($root);
+			}
 		}
 		else
 		{
-			$records = array();
+			$fnames = array();
 		}
 
+		// get results based on last name
+		if (isset($last_name))
+		{
+			$root = $this->_fetchXml(NULL, $last_name, NULL);
+			if (!empty($root))
+			{
+				$lnames = $this->_parseTree($root);
+			}
+		}
+		else
+		{
+			$lnames = array();
+		}
+
+		// get results based on email
+		if (isset($email))
+		{
+			$root = $this->_fetchXml(NULL, NULL, $email);
+
+			if (!empty($root))
+			{
+				$emails = $this->_parseTree($root);
+			}
+		}
+		else
+		{
+			$emails = array();
+		}
+
+		// combine
+		$records = array_merge((array)$fnames, (array)$lnames, (array)$emails);
+
 		ob_end_clean();
 		ob_start();
 
@@ -335,7 +376,8 @@ class MembersControllerOrcid extends \Hubzero\Component\SiteController
 		$output->message = '';
 
 		$srv = $this->config->get('orcid_service', 'members');
-		$url = JURI::getInstance()->getScheme() . '://' . $this->_services[$srv] . '/orcid-profile';
+		$url = JURI::getInstance()->getScheme() . '://' . $this->_services[$srv] . '/v1.2' . '/orcid-profile';
+
 		$tkn = $this->config->get('orcid_' . $srv . '_token');
 
 		if (!$tkn)
@@ -365,8 +407,8 @@ class MembersControllerOrcid extends \Hubzero\Component\SiteController
 					'<orcid-message'.
 						' xmlns="http://www.orcid.org/ns/orcid"'.
 						' xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"'.
-						' xsi:schemaLocation="https://raw.github.com/ORCID/ORCID-Source/master/orcid-model/src/main/resources/orcid-message-1.1.xsd">'.
-						'<message-version>1.1</message-version>'.
+						' xsi:schemaLocation="https://raw.github.com/ORCID/ORCID-Source/master/orcid-model/src/main/resources/orcid-message-1.2.xsd">'.
+						'<message-version>1.2</message-version>'.
 						'<orcid-profile>'.
 							'<orcid-bio>'.
 								'<personal-details>'.
