@@ -161,6 +161,7 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 		$filters['limit']  = 20;
 		$filters['start']  = 0;
 		$filters['search'] = strtolower(trim(JRequest::getString('value', '')));
+		$originalQuery = $filters['search'];
 
 		// match against orcid id
 		if (preg_match('/\d{4}-\d{4}-\d{4}-\d{4}/', $filters['search']))
@@ -227,6 +228,23 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 			}
 		}
 
+		// formats names in the autocompleter
+		if (!\Hubzero\Utility\Validate::email($originalQuery) && str_word_count($originalQuery) >= 2)
+		{
+			$originalQuery = ucwords($originalQuery);
+		}
+
+		//original query
+		$obj = array();
+		$obj['name'] = $originalQuery;
+		$obj['id'] = $originalQuery;
+		$obj['org'] = '';
+		$obj['picture'] = '';
+		$obj['orig'] = true;
+
+		//add back original query
+		array_unshift($json, $obj);
+
 		echo json_encode($json);
 	}
 
@@ -488,7 +506,7 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 		}
 
 		// Incoming
-		$id = JRequest::getInt('id', 0);
+		$id  = JRequest::getVar('id', 0);
 		$tab = JRequest::getVar('active', 'dashboard');  // The active tab (section)
 
 		// Get plugins
@@ -496,7 +514,7 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 		$dispatcher = JDispatcher::getInstance();
 
 		// Ensure we have an ID
-		if (!$id)
+		if (!$id || !is_numeric($id))
 		{
 			$pathway->addItem(
 				JText::_(strtoupper($this->_task)),
@@ -506,6 +524,8 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 			return;
 		}
 
+		$id = intval($id);
+
 		// Check administrative access
 		$this->view->authorized = $this->_authorize($id);
 
@@ -699,7 +719,7 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 		$profile = \Hubzero\User\Profile::getInstance($id);
 
 		// Ensure we have a member
-		if (!$profile->get('name'))
+		if (!$profile || !$profile->get('name'))
 		{
 			$pathway->addItem(
 				JText::_(strtoupper($this->_task)),
@@ -779,6 +799,9 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 			return;
 		}
 
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		$passrules = false;
 
 		if (!\Hubzero\User\Password::passwordMatches($profile->get('uidNumber'), $oldpass, true))
@@ -1352,6 +1375,9 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 			return false;
 		}
 
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		$no_html = JRequest::getVar("no_html", 0);
 
 		// Incoming user ID
@@ -1360,7 +1386,7 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 		// Do we have an ID?
 		if (!$id)
 		{
-			JError::raiseError(500, JText::_('MEMBERS_NO_ID'));
+			JError::raiseError(404, JText::_('MEMBERS_NO_ID'));
 			return;
 		}
 
@@ -1394,6 +1420,11 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 		{
 			foreach ($a as $k => $v)
 			{
+				$v = intval($v);
+				if (!in_array($v, array(0, 1, 2, 3, 4)))
+				{
+					$v = 0;
+				}
 				$profile->setParam('access_' . $k, $v);
 			}
 		}
@@ -1695,7 +1726,7 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 		// Do we have an ID?
 		if (!$id)
 		{
-			JError::raiseError(500, JText::_('MEMBERS_NO_ID'));
+			JError::raiseError(404, JText::_('MEMBERS_NO_ID'));
 			return;
 		}
 
@@ -1706,8 +1737,13 @@ class MembersControllerProfiles extends \Hubzero\Component\SiteController
 			// Load the profile
 			$profile = \Hubzero\User\Profile::getInstance($id);
 
-			foreach ($p as $k=>$v)
+			foreach ($p as $k => $v)
 			{
+				$v = intval($v);
+				if (!in_array($v, array(0, 1, 2, 3, 4)))
+				{
+					$v = 0;
+				}
 				$profile->setParam('access_' . $k, $v);
 			}
 
