@@ -394,7 +394,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 		$message = (!empty($this->xregistration->_invalid['countryorigin'])) ? '<p class="error">' . $this->xregistration->_invalid['countryorigin'] . '</p>' : '';
 		$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 
-		$countryorigin = $this->profile->get('countryorigin');
+		$countryorigin = strtoupper($this->profile->get('countryorigin'));
 
 		$html .= "\t\t".'<fieldset'.$fieldclass.'>'."\n";
 		$html .= "\t\t\t".'<legend>'.JText::_('Are you a Legal Citizen or Permanent Resident of the <abbr title="United States">US</abbr>?').$required.'</legend>'."\n";
@@ -418,7 +418,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 		{
 			if ($country->code != 'US') {
 				$html .= "\t\t\t\t".' <option value="' . $country->code . '"';
-				if ($countryorigin == $country->code) {
+				if ($countryorigin == strtoupper($country->code)) {
 					$html .= ' selected="selected"';
 				}
 				$html .= '>' . $this->escape($country->name) . '</option>'."\n";
@@ -433,7 +433,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 		$message = (!empty($this->xregistration->_invalid['countryresident'])) ? '<p class="error">' . $this->xregistration->_invalid['countryresident'] . '</p>' : '';
 		$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 
-		$countryresident = $this->profile->get('countryresident');
+		$countryresident = strtoupper($this->profile->get('countryresident'));
 
 		$html .= "\t\t".'<fieldset'.$fieldclass.'>';
 		$html .= "\t\t\t".'<legend>'.JText::_('Do you Currently Live in the <abbr title="United States">US</abbr>?').$required.'</legend>'."\n";
@@ -457,7 +457,7 @@ if ($this->registration->Citizenship != REG_HIDE || $this->registration->Residen
 		{
 			if (strcasecmp($country->code,"US") != 0) {
 				$html .= "\t\t\t"."\t\t".'<option value="' . $country->code . '"';
-				if (strcasecmp($countryresident,$country->code) == 0) {
+				if ($countryresident == strtoupper($country->code)) {
 					$html .= ' selected="selected"';
 				}
 				$html .= '>' . $this->escape($country->name) . '</option>'."\n";
@@ -716,7 +716,7 @@ $html .= "<a name=\"memberpicture\"></a>";
 $html .= "\t\t".'<legend>'.JText::_('MEMBER_PICTURE').'</legend>'."\n";
 $html .= "\t\t".'<iframe width="100%" height="350" border="0" name="filer" id="filer" src="index.php?option='.$this->option.'&amp;controller=media&amp;tmpl=component&amp;file='.stripslashes($this->profile->get('picture')).'&amp;id='.$this->profile->get('uidNumber').'"></iframe>'."\n";
 $html .= "\t".'</fieldset><div class="clear"></div>'."\n";
-
+$html .= JHTML::_('form.token');
 $html .= "\t".'<p class="submit"><input class="btn btn-success" type="submit" name="submit" value="'.JText::_('SAVE').'" /></p>'."\n";
 $html .= '</form>'."\n";
 $html .= '</section>'."\n";
