@@ -29,17 +29,14 @@
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
+
+$this->css()
+	 ->css('jquery.fancybox.css', 'system')
+     ->js();
 ?>
 
 <div id="abox-content">
 <?php
-/*
-if (!is_file(JPATH_ROOT . $this->url))
-{
-	echo '<p class="error">'.JText::_('COM_PUBLICATIONS_FILE_NOT_FOUND').'</p>'."\n";
-	return;
-}
-*/
 
 $oWidth = '780';
 $oHeight= '480';
@@ -54,18 +51,18 @@ $width 		= (intval($width) > 0) ? $width : $oWidth;
 $height 	= (intval($height) > 0) ? $height : $oHeight;
 
 // Get mime type
-$mTypeParts = explode(';', $this->mimetype);						
+$mTypeParts = explode(';', $this->mimetype);
 $cType 		= $mTypeParts[0];
 
-if ($attributes) 
+if ($attributes)
 {
 	$a = explode(',', $attributes);
 	$bits = array();
-	if ($a && is_array($a)) 
+	if ($a && is_array($a))
 	{
-		foreach ($a as $b) 
+		foreach ($a as $b)
 		{
-			if (strstr($b, ':')) 
+			if (strstr($b, ':'))
 			{
 				$b = explode(':', $b);
 				$bits[] = trim($b[0]) . '="' . trim($b[1]) . '"';
@@ -76,8 +73,8 @@ if ($attributes)
 }
 
 // Formats that can be previewed via Google viewer
-$docs 	= array('pdf', 'doc', 'docx', 'xls', 'xlsx', 
-	'ppt', 'pptx', 'pages', 'ai', 
+$docs 	= array('pdf', 'doc', 'docx', 'xls', 'xlsx',
+	'ppt', 'pptx', 'pages', 'ai',
 	'psd', 'tiff', 'dxf', 'eps', 'ps', 'ttf', 'xps', 'svg'
 );
 
@@ -90,49 +87,49 @@ if (!$juser->get('guest'))
 	$session = JFactory::getSession();
 
 	$session_id = $session->getId();
-	
+
 	jimport('joomla.utilities.simplecrypt');
 	$crypter = new JSimpleCrypt();
 	$token = base64_encode($crypter->encrypt($session_id));
 }
 
 $juri = JURI::getInstance();
-$downloadUrl = JRoute::_('index.php?option=com_publications&id=' . $this->publication->id . '&task=serve&aid=' 
+$downloadUrl = JRoute::_('index.php?option=com_publications&id=' . $this->publication->id . '&task=serve&aid='
 	  . $this->aid . '&render=download&token=' . $token);
 
-$viewUrl = JRoute::_('index.php?option=com_publications&id=' . $this->publication->id . '&task=serve&aid=' 
+$viewUrl = JRoute::_('index.php?option=com_publications&id=' . $this->publication->id . '&task=serve&aid='
 	  . $this->aid . '&render=download&disposition=inline&token=' . $token);
-	
+
 ?>
 <div class="sample"><p><?php echo JText::_('COM_PUBLICATIONS_PUBLICATION') . ': <strong>' . $this->publication->title . '</strong>'; ?> <?php if ($this->primary->role != 1) { echo '&nbsp;&nbsp; Supporting Doc: <strong>' . $this->primary->path . '</strong>'; } ?></p></div>
 
 <?php
 // Image?
-if ($this->type == 'image') 
+if ($this->type == 'image')
 {
 	echo '<img ' . $attributes . ' src="' . $this->url . '" alt="Image" />'."\n";
 }
-elseif (in_array(strtolower($this->ext), $docs) && $this->googleView) 
-{	
+elseif (in_array(strtolower($this->ext), $docs) && $this->googleView)
+{
 	// View via Google
-	echo  '<iframe src="https://docs.google.com/viewer?url=' . urlencode($juri->base() 
+	echo  '<iframe src="https://docs.google.com/viewer?url=' . urlencode($juri->base()
 			. $downloadUrl) . '&amp;embedded=true#:0.page.0" width="100%" height="500" name="file_resource" frameborder="0" bgcolor="white"></iframe>'
 			."\n";
 }
 else
-		// View in html5-browser 
+		// View in html5-browser
 		{ ?>
 			<p class="direct-download">Publication doesn't load in your browser or shows partial file? <a href="<?php echo $juri->base() . $downloadUrl; ?>">Download file</a>
 			</p>
-		<?php 
+		<?php
 	if (strtolower($this->ext) == 'wmv') { ?>
-	<object type="video/x-ms-wmv" 
+	<object type="video/x-ms-wmv"
 		  data="<?php echo $this->url; ?>" width="100%" height="<?php echo $height; ?>">
 		  <param name="src" value="<?php echo $this->url; ?>" />
 		  <param name="autostart" value="true" />
 		  <param name="controller" value="true" />
 	</object>
-<?php } else { 
+<?php } else {
 	 ?>
 	<div class="video-container">
 		<object width="100%" height="<?php echo $height; ?>">
