@@ -1102,7 +1102,7 @@ class ToolsControllerPipeline extends \Hubzero\Component\SiteController
 			$hztv->toolaccess    = $tool['exec'];
 			$hztv->codeaccess    = $tool['code'];
 			$hztv->wikiaccess    = $tool['wiki'];
-			$hztv->vnc_command   = $invokedir . DS . $tool['toolname'] . DS . 'dev' . DS . 'middleware' . DS . 'invoke -T dev';
+			$hztv->vnc_command   = $invokedir . DS . $tool['toolname'] . DS . 'dev' . DS . 'middleware' . DS . 'invoke';
 			$hztv->vnc_geometry  = $tool['vncGeometry'];
 			$hztv->exportControl = $exportmap[$tool['exec']];
 			$hztv->state         = 3;
@@ -2369,7 +2369,7 @@ class ToolsControllerPipeline extends \Hubzero\Component\SiteController
 	{
 		$token = md5(uniqid());
 
-		$fname = '/tmp/license' . $toolname . $token . 'txt';
+		$fname = '/tmp/license' . $toolname . $token . '.txt';
 		$handle = fopen($fname, "w");
 
 		fwrite($handle, $this->_output);
@@ -2379,6 +2379,7 @@ class ToolsControllerPipeline extends \Hubzero\Component\SiteController
 
 		if (!$this->_invokescript($command, JText::_('COM_TOOLS_NOTICE_LICENSE_CHECKED_IN'), $output))
 		{
+			unlink($fname);
 			return false;
 		}
 		else
