@@ -180,6 +180,11 @@ class WikiControllerPage extends \Hubzero\Component\SiteController
 		// Does a page exist for the given pagename?
 		if (!$this->page->exists() || $this->page->isDeleted())
 		{
+			if (!$this->page->access('create'))
+			{
+				JError::raiseError(404, JText::_('COM_WIKI_WARNING_PAGE_DOES_NOT_EXIST'));
+			}
+
 			// No! Ask if they want to create a new page
 			$this->view->setLayout('doesnotexist');
 			if ($this->_group)
@@ -989,8 +994,10 @@ class WikiControllerPage extends \Hubzero\Component\SiteController
 		// Does a page exist for the given pagename?
 		if (!$this->page->exists() || $this->page->isDeleted())
 		{
+			JError::raiseError(404, JText::_('COM_WIKI_WARNING_NOT_FOUND'));
+
 			// No! Ask if they want to create a new page
-			$this->view->setLayout('doesnotexist');
+			/*$this->view->setLayout('doesnotexist');
 			if ($this->_group)
 			{
 				$this->page->set('group_cn', $this->_group);
@@ -1005,7 +1012,7 @@ class WikiControllerPage extends \Hubzero\Component\SiteController
 				}
 			}
 			$this->view->display();
-			return;
+			return;*/
 		}
 
 		// Retrieve a specific version if given
