@@ -282,14 +282,43 @@ class Repository extends Base implements CommandInterface
 			$response = $this->mechanism->update(false, $allowNonFf);
 			if ($response['status'] == 'success')
 			{
-				if ($mode != 'minimal')
+				// Now, check to see whether or not we need to go ahead and push this merge elsewhere
+				if ($ref = $this->arguments->getOpt('git-auto-push-ref', false))
 				{
-					$this->output->addLine(
-						'complete',
-						array(
-							'color' => 'green'
-						)
-					);
+					$response = $this->mechanism->push($ref);
+					if ($response['status'] === 'success')
+					{
+						if ($mode != 'minimal')
+						{
+							$this->output->addLine(
+								'complete',
+								array(
+									'color' => 'green'
+								)
+							);
+						}
+					}
+					else
+					{
+						$this->output->addLine(
+							strtolower($response['message']),
+							array(
+								'color' => 'red'
+							)
+						);
+					}
+				}
+				else
+				{
+					if ($mode != 'minimal')
+					{
+						$this->output->addLine(
+							'complete',
+							array(
+								'color' => 'green'
+							)
+						);
+					}
 				}
 			}
 			else if ($response['status'] == 'fatal')
@@ -419,16 +448,35 @@ class Repository extends Base implements CommandInterface
 				$performed++;
 			}
 
-			$this->output->addLine("Clean up complete. Performed ({$performed}/1) cleanup operations available.");
+			$proceed = $this->output->getResponse('Do you want to purge all stashed changes? [y|n]');
+
+			if ($proceed == 'y' || $proceed == 'yes')
+			{
+				$this->mechanism->purgeStash();
+				$this->output->addLine('Purging repository stash.');
+				$performed++;
+			}
+
+			$this->output->addLine("Clean up complete. Performed ({$performed}/2) cleanup operations available.");
 		}
 		else
 		{
+			$didSomething = false;
 			if ($this->arguments->getOpt('purge-rollback-points'))
 			{
 				$this->mechanism->purgeRollbackPoints();
 				$this->output->addLine('Purging rollback points.');
+				$didSomething = true;
 			}
-			else
+
+			if ($this->arguments->getOpt('purge-stash'))
+			{
+				$this->mechanism->purgeStash();
+				$this->output->addLine('Purging repository stash.');
+				$didSomething = true;
+			}
+
+			if (!$didSomething)
 			{
 				$this->output->addLine('Please specify which cleanup operations to perform');
 			}
