@@ -1,17 +1,19 @@
 <?php
 
+use Hubzero\Content\Migration\Base;
+
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
 /**
  * Migration script for adding indices to pdf2form tables
  **/
-class Migration20130812132139ComCollections extends Hubzero_Migration
+class Migration20130812132139ComCollections extends Base
 {
 	/**
 	 * Up
 	 **/
-	protected static function up($db)
+	public function up()
 	{
 		$query = "CREATE TABLE IF NOT EXISTS `#__collections` (
 				  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
@@ -103,16 +105,16 @@ class Migration20130812132139ComCollections extends Hubzero_Migration
 				  KEY `idx_item_user` (`item_id`,`user_id`)
 				) ENGINE=MyISAM DEFAULT CHARSET=utf8;";
 
-		$db->setQuery($query);
-		$db->query();
+		$this->db->setQuery($query);
+		$this->db->query();
 
-		self::addComponentEntry('Collections');
+		$this->addComponentEntry('Collections');
 	}
 
 	/**
 	 * Down
 	 **/
-	protected static function down($db)
+	public function down()
 	{
 		$query = "DROP TABLE IF EXISTS `#__collections`;
 				DROP TABLE IF EXISTS `#__collections_assets`;
@@ -120,9 +122,9 @@ class Migration20130812132139ComCollections extends Hubzero_Migration
 				DROP TABLE IF EXISTS `#__collections_items`;
 				DROP TABLE IF EXISTS `#__collections_posts`;
 				DROP TABLE IF EXISTS `#__collections_votes`;";
-		$db->setQuery($query);
-		$db->query();
+		$this->db->setQuery($query);
+		$this->db->query();
 
-		self::deleteComponentEntry('Collections');
+		$this->deleteComponentEntry('Collections');
 	}
 }
