@@ -1,23 +1,25 @@
 <?php
 
+use Hubzero\Content\Migration\Base;
+
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
 /**
  * Migration script for replacing odd characters in resource license text
  **/
-class Migration20131113193815ComResources extends Hubzero_Migration
+class Migration20131113193815ComResources extends Base
 {
 	/**
 	 * Up
 	 **/
-	protected static function up($db)
+	public function up()
 	{
-		if ($db->tableExists('#__resource_licenses'))
+		if ($this->db->tableExists('#__resource_licenses'))
 		{
 			$query = "UPDATE `#__resource_licenses` SET `text` = REPLACE(`text`, 'â€”', '—')";
-			$db->setQuery($query);
-			$db->query();
+			$this->db->setQuery($query);
+			$this->db->query();
 		}
 	}
 }
\ No newline at end of file
