@@ -284,8 +284,10 @@ class plgCoursesDiscussions extends \Hubzero\Plugin\Plugin
 				foreach ($categories as $category)
 				{
 					$ids[] = $category->id;
+					$cat   = new ForumTableCategory($db);
+					$cat->load($category->id);
+					$cat->setStateBySection($section->id, 2);
 				}
-				$section->setStateBySection($section->id, 2);
 
 				$thread = new ForumTablePost($db);
 				$thread->setStateByCategory($ids, 2);
@@ -306,6 +308,7 @@ class plgCoursesDiscussions extends \Hubzero\Plugin\Plugin
 		$response = with(new \Hubzero\Base\Object)
 			->set('name', $this->_name)
 			->set('title', JText::_('PLG_COURSES_' . strtoupper($this->_name)))
+			->set('description', JText::_('PLG_COURSES_' . strtoupper($this->_name) . '_BLURB'))
 			->set('default_access', $this->params->get('plugin_access', 'members'))
 			->set('display_menu_tab', true)
 			->set('icon', 'f086');
