@@ -56,6 +56,7 @@ class plgCoursesPages extends \Hubzero\Plugin\Plugin
 		$response = with(new \Hubzero\Base\Object)
 			->set('name', $this->_name)
 			->set('title', JText::_('PLG_COURSES_' . strtoupper($this->_name)))
+			->set('description', JText::_('PLG_COURSES_' . strtoupper($this->_name) . '_BLURB'))
 			->set('default_access', $this->params->get('plugin_access', 'members'))
 			->set('display_menu_tab', true)
 			->set('icon', 'f05a');
@@ -498,6 +499,16 @@ class plgCoursesPages extends \Hubzero\Plugin\Plugin
 			move_uploaded_file($_FILES['qqfile']['tmp_name'], $file);
 		}
 
+		if (!JFile::isSafe($file))
+		{
+			JFile::delete($file);
+
+			ob_clean();
+			header('Content-type: text/plain');
+			echo json_encode(array('error' => JText::_('File rejected because the anti-virus scan failed.')));
+			return;
+		}
+
 		ob_clean();
 		header('Content-type: text/plain');
 		echo json_encode(array(
@@ -570,6 +581,13 @@ class plgCoursesPages extends \Hubzero\Plugin\Plugin
 			$this->setError(JText::_('PLG_COURSES_PAGES_ERROR_UNABLE_TO_UPLOAD'));
 		}
 
+		if (!JFile::isSafe($path . DS . $file['name']))
+		{
+			JFile::delete($path . DS . $file['name']);
+
+			$this->setError(JText::_('PLG_COURSES_PAGES_ERROR_UNSAFE_FILE'));
+		}
+
 		// Push through to the media view
 		return $this->_files();
 	}
