@@ -263,10 +263,22 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 			{
 				$path = str_replace($juri->base(true), '', $path);
 				$path = str_replace('index.php', '', $path);
-				$path = DS . trim($path, DS);
-				$path = str_replace('/groups/' . $this->group->get('cn') . '/' . $this->_name, '', $path);
-				$path = ltrim($path, DS);
-				$bits = explode('/', $path);
+				$path = trim($path, '/');
+				$parts = explode('/', $path);
+				$start = false;
+				$bits = array();
+				foreach ($parts as $p)
+				{
+					if ($p == $this->_name)
+					{
+						$start = true;
+						continue;
+					}
+					if ($start)
+					{
+						$bits[] = $p;
+					}
+				}
 
 				if (isset($bits[0]) && $bits[0])
 				{
@@ -448,6 +460,10 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 		if (!$this->params->get('access-manage-collection'))
 		{
 			$view->filters['access'] = ($this->juser->get('guest') ? 0 : array(0, 1));
+			if (in_array($this->juser->get('id'), $this->group->get('members')))
+			{
+				$view->filters['access'] = array(0, 1, 4);
+			}
 			$count['access'] = $view->filters['access'];
 		}
 
@@ -522,6 +538,16 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 			'count'  => true
 		);
 
+		if (!$this->params->get('access-manage-collection'))
+		{
+			$count['access'] = ($this->juser->get('guest') ? 0 : array(0, 1));
+			if (in_array($this->juser->get('id'), $this->group->get('members')))
+			{
+				$count['access'] = array(0, 1, 4);
+			}
+			$filters['access'] = $count['access'];
+		}
+
 		$filters['count'] = true;
 		$view->total = $this->model->collections($filters);
 
@@ -616,6 +642,10 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 		if (!$this->params->get('access-manage-collection'))
 		{
 			$view->filters['access'] = ($this->juser->get('guest') ? 0 : array(0, 1));
+			if (in_array($this->juser->get('id'), $this->group->get('members')))
+			{
+				$view->filters['access'] = array(0, 1, 4);
+			}
 			$count['access'] = $view->filters['access'];
 		}
 		if ($this->authorized)
@@ -821,6 +851,10 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 		if (!$this->params->get('access-manage-collection'))
 		{
 			$view->filters['access'] = ($this->juser->get('guest') ? 0 : array(0, 1));
+			if (in_array($this->juser->get('id'), $this->group->get('members')))
+			{
+				$view->filters['access'] = array(0, 1, 4);
+			}
 			$count['access'] = $view->filters['access'];
 		}
 		if ($this->authorized)
@@ -1005,7 +1039,7 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 			$view->collection = $this->model->collection(JRequest::getVar('board', 0));
 		}
 
-		$view->entry = $view->collection->post($id);
+		$view->entry = (is_object($entry) ? $entry : $view->collection->post($id));
 		if (!$view->collection->exists() && $view->entry->exists())
 		{
 			$view->collection = $this->model->collection($view->entry->get('collection_id'));
@@ -1019,6 +1053,11 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 			}
 		}
 
+		foreach ($this->getErrors() as $error)
+		{
+			$view->setError($error);
+		}
+
 		if ($no_html)
 		{
 			$view->display();
@@ -1056,6 +1095,11 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 		// Incoming
 		$fields = JRequest::getVar('fields', array(), 'post', 'none', 2);
 
+		if ($fields['id'] && !is_numeric($fields['id']))
+		{
+			JError::raiseError(404, JText::_('Post does not exist'));
+		}
+
 		// Get model
 		$row = new CollectionsModelItem($fields['id']);
 
@@ -1096,17 +1140,21 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 			$post->set('original', 1);
 		}
 
-		$coltitle = JRequest::getVar('collection_title', '', 'post');
-		if (!$p['collection_id'] && $coltitle)
+		if (!isset($p['collection_id']))
 		{
-			$collection = new CollectionsModelCollection();
-			$collection->set('title', $coltitle);
-			$collection->set('object_id', $this->group->get('gidNumber'));
-			$collection->set('object_type', 'group');
-			$collection->set('access', $this->params->get('access-plugin'));
-			$collection->store();
+			$p['collection_id'] = 0;
 
-			$p['collection_id'] = $collection->get('id');
+			if ($coltitle = Request::getVar('collection_title', '', 'post'))
+			{
+				$collection = new CollectionsModelCollection();
+				$collection->set('title', $coltitle);
+				$collection->set('object_id', $this->group->get('gidNumber'));
+				$collection->set('object_type', 'group');
+				$collection->set('access', $this->params->get('access-plugin'));
+				$collection->store();
+
+				$p['collection_id'] = $collection->get('id');
+			}
 		}
 
 		$post->set('collection_id', $p['collection_id']);
@@ -1122,7 +1170,8 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 		// Check for any errors
 		if ($this->getError())
 		{
-			return $this->_edit($row);
+			JRequest::setVar('post', $p['id']);
+			return $this->_edit($post->item()->bind($fields));
 		}
 
 		$this->redirect(
@@ -1383,7 +1432,7 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 		$collection = $this->model->collection($post->get('collection_id'));
 
 		// Did they confirm delete?
-		if (!$process || !$confirmdel || !JRequest::checkToken())
+		if (!$process || !$confirmdel)
 		{
 			if ($process && !$confirmdel)
 			{
@@ -1423,6 +1472,8 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 			return $view->loadTemplate();
 		}
 
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		$msg = JText::_('PLG_GROUPS_COLLECTIONS_POST_DELETED');
 		$type = 'passed';
 
@@ -1665,6 +1716,7 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 
 		// Incoming
 		$fields = JRequest::getVar('fields', array(), 'post', 'none', 2);
+		$fields['id'] = intval($fields['id']);
 
 		// Bind new content
 		$row = new CollectionsModelCollection();
@@ -1758,6 +1810,8 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 			return $view->loadTemplate();
 		}
 
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// Mark the entry as deleted
 		$collection->set('state', 2);
 		if (!$collection->store())
@@ -1792,8 +1846,7 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 
 		if ($this->authorized != 'manager' && $this->authorized != 'admin')
 		{
-			$this->setError(JText::_('PLG_GROUPS_COLLECTIONS_NOT_AUTH'));
-			return $this->_browse();
+			JError::raiseError(403, JText::_('PLG_GROUPS_COLLECTIONS_NOT_AUTH'));
 		}
 
 		// Output HTML
@@ -1844,14 +1897,17 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 			return $this->_collections();
 		}
 
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		$settings = JRequest::getVar('settings', array(), 'post');
 
 		$row = new \Hubzero\Plugin\Params($this->database);
-		if (!$row->bind($settings))
-		{
-			$this->setError($row->getError());
-			return $this->_settings();
-		}
+		$row->loadPlugin($this->group->get('gidNumber'), $this->_type, $this->_name);
+
+		$row->object_id = $this->group->get('gidNumber');
+		$row->folder    = $this->_type;
+		$row->element   = $this->_name;
 
 		// Get parameters
 		$prms = JRequest::getVar('params', array(), 'post');
@@ -1916,8 +1972,10 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 			$this->params->merge($customParams);
 
 			// Set asset to viewable
+			$isMember = in_array($this->juser->get('id'), $this->members);
+
 			$this->params->set('access-view-' . $assetType, false);
-			if (in_array($this->juser->get('id'), $this->members))
+			if ($isMember)
 			{
 				$this->params->set('access-view-' . $assetType, true);
 			}
@@ -1938,7 +1996,7 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 						$this->params->set('access-edit-' . $assetType, true);
 						$this->params->set('access-view-' . $assetType, true);
 					}
-					if (!$this->params->get('create_collection', 1))
+					if (!$this->params->get('create_collection', 1) && $isMember)
 					{
 						$this->params->set('access-create-' . $assetType, true);
 						$this->params->set('access-delete-' . $assetType, true);
@@ -1956,7 +2014,7 @@ class plgGroupsCollections extends \Hubzero\Plugin\Plugin
 						$this->params->set('access-edit-' . $assetType, true);
 						$this->params->set('access-view-' . $assetType, true);
 					}
-					if (!$this->params->get('create_post', 0))
+					if (!$this->params->get('create_post', 0) && $isMember)
 					{
 						$this->params->set('access-create-' . $assetType, true);
 						$this->params->set('access-delete-' . $assetType, true);
