@@ -181,6 +181,7 @@ $isIncrementalEnabled = $incrOpts->isEnabled($uid);
 				<input type="hidden" name="option" value="com_members" />
 				<input type="hidden" name="id" value="<?php echo $juser->get("id"); ?>" />
 				<input type="hidden" name="task" value="save" />
+				<?php echo JHTML::_('form.token'); ?>
 			</form>
 		</div>
 	<?php endif; ?>
@@ -251,6 +252,7 @@ $isIncrementalEnabled = $incrOpts->isEnabled($uid);
 									<input type="hidden" name="id" value="<?php echo $this->profile->get('uidNumber'); ?>" />
 									<input type="hidden" name="task" value="changepassword" />
 									<input type="hidden" name="no_html" value="1" />
+									<?php echo JHTML::_('form.token'); ?>
 								</form>
 							</div>
 						</div>
@@ -879,7 +881,7 @@ $isIncrementalEnabled = $incrOpts->isEnabled($uid);
 							// get the country name
 							foreach ($co as $c)
 							{
-								if ($c->code == strtoupper($this->profile->get('countryorigin')))
+								if (strtoupper($c->code) == strtoupper($this->profile->get('countryorigin')))
 								{
 									$citizenship = $c->name;
 								}
@@ -898,7 +900,7 @@ $isIncrementalEnabled = $incrOpts->isEnabled($uid);
 							foreach ($co as $c)
 							{
 								$countries .= '<option value="' . $c->code . '"';
-								if ($this->profile->get('countryorigin') == $c->code)
+								if (strtoupper($this->profile->get('countryorigin')) == strtoupper($c->code))
 								{
 									$countries .= ' selected="selected"';
 								}
@@ -980,7 +982,7 @@ $isIncrementalEnabled = $incrOpts->isEnabled($uid);
 							// get the country name
 							foreach ($co as $c)
 							{
-								if ($c->code == strtoupper($this->profile->get('countryresident')))
+								if (strtoupper($c->code) == strtoupper($this->profile->get('countryresident')))
 								{
 									$residence = $c->name;
 								}
@@ -998,7 +1000,7 @@ $isIncrementalEnabled = $incrOpts->isEnabled($uid);
 							foreach ($co as $c)
 							{
 								$countries .= '<option value="' . $c->code . '"';
-								if ($this->profile->get('countryresident') == $c->code)
+								if (strtoupper($this->profile->get('countryresident')) == strtoupper($c->code))
 								{
 									$countries .= ' selected="selected"';
 								}
